@@ -1,9 +1,9 @@
 """Normalize and debug a TAP (application profile in DCTAP format)."""
 
-from .tapclasses import TAPShape, TAPStatementTemplate
-from .csvreader import csvreader
+from dctap.tapclasses import TAPShape, TAPStatementTemplate
+from dctap.csvreader import csvreader
 
-__version__ = "0.3.15"
+__version__ = "0.4.2"
 
 # Keep version number in sync with:
 # - https://github.com/dcmi/dctap-python/blob/main/docs/conf.py#L28
