@@ -4,13 +4,12 @@ import sys
 import json as j
 from ruamel.yaml import YAML
 import click
-from .defaults import DEFAULT_CONFIGFILE_NAME, DEFAULT_HIDDEN_CONFIGFILE_NAME
-from .config import get_config, write_configfile
-from .csvreader import csvreader
-from .inspect import pprint_tapshapes, print_warnings
-from .loggers import stderr_logger
-from .tapclasses import TAPShape, TAPStatementTemplate
-from .utils import expand_uri_prefixes
+from dctap.defaults import CONFIGFILE
+from dctap.config import get_config, write_configfile
+from dctap.csvreader import csvreader
+from dctap.inspect import pprint_tapshapes, print_warnings
+from dctap.loggers import stderr_logger
+from dctap.utils import expand_uri_prefixes
 
 # pylint: disable=unused-argument,no-value-for-parameter
 # => unused-argument: Allows placeholders for now.
@@ -18,7 +17,7 @@ from .utils import expand_uri_prefixes
 
 
 @click.group()
-@click.version_option("0.3.15", help="Show version and exit")
+@click.version_option("0.4.2", help="Show version and exit")
 @click.help_option(help="Show help and exit")
 @click.pass_context
 def cli(context):
@@ -29,7 +28,6 @@ def cli(context):
     \b
     Write starter config file:
     $ dctap init                           # Write dctap.yaml
-    $ dctap init --hidden                  # Write .dctaprc
     \b
     Show normalized view of TAP:
     $ dctap read x.csv                     # Output as plain text
@@ -40,15 +38,11 @@ def cli(context):
 
 
 @cli.command()
-@click.option("--hidden", default=False, help="Write as dot file [.dctaprc]")
 @click.help_option(help="Show help and exit")
 @click.pass_context
 def init(context, hidden):
-    """Write config file [dctap.yaml]"""
-    if hidden:
-        configfile = DEFAULT_HIDDEN_CONFIGFILE_NAME
-    else:
-        configfile = DEFAULT_CONFIGFILE_NAME
+    """Write config file: 'dctap.yaml'."""
+    configfile = CONFIGFILE
     write_configfile(configfile)
 
 
@@ -65,13 +59,11 @@ def read(context, csvfile_obj, config, expand_prefixes, warnings, json, yaml):
     """Show TAP as TXT, JSON, or YAML."""
     # pylint: disable=too-many-locals,too-many-arguments
 
-    config_dict = get_config(configfile_name=config)
-    tapshapes_dict = csvreader(
-        open_csvfile_obj=csvfile_obj,
-        config_dict=config_dict,
-        shape_class=TAPShape,
-        state_class=TAPStatementTemplate,
-    )
+    if config:
+        config_dict = get_config(nondefault_configfile_name=config)
+    else:
+        config_dict = get_config()
+    tapshapes_dict = csvreader(open_csvfile_obj=csvfile_obj, config_dict=config_dict)
 
     if expand_prefixes:
         tapshapes_dict = expand_uri_prefixes(tapshapes_dict, config_dict)
@@ -97,10 +89,7 @@ def read(context, csvfile_obj, config, expand_prefixes, warnings, json, yaml):
 
     if not (json or yaml):
         pprint_output = pprint_tapshapes(
-            tapshapes_dict=tapshapes_dict,
-            config_dict=config_dict,
-            shape_class=TAPShape,
-            state_class=TAPStatementTemplate,
+            tapshapes_dict=tapshapes_dict, config_dict=config_dict
         )
         for line in pprint_output:
             print(line, file=sys.stdout)
