@@ -1,13 +1,9 @@
 """Default settings."""
 
-DEFAULT_CONFIGFILE_NAME = "dctap.yaml"
-
-DEFAULT_HIDDEN_CONFIGFILE_NAME = ".dctaprc"
-
-DEFAULT_CONFIG_YAML = """### dctap configuration file (in YAML format)
-
-# See https://dctap-python.readthedocs.io/en/latest/config/
-# for advanced configuration options
+CONFIGFILE = "dctap.yaml"
+CONFIGYAML = """\
+# dctap configuration file (in YAML format)
+# See https://dctap-python.readthedocs.io/en/latest/config/ for more options
 
 prefixes:
     ":":        "http://example.org/"
@@ -23,16 +19,4 @@ prefixes:
     "skosxl:":  "http://www.w3.org/2008/05/skos-xl#"
     "wdt:":     "http://www.wikidata.org/prop/direct/"
     "xsd:":     "http://www.w3.org/2001/XMLSchema#"
-
-### Element aliases for shorter, translated, or preferred CSV column names.
-# extra_element_aliases:
-#     "PropID": "propertyID"
-#     "PropLabel": "propertyLabel"
-#     "Value": "valueConstraint"
-#     "ValueType": "valueConstraintType"
-#     "DataType": "valueDataType"
-#     "NodeType": "valueNodeType"
-#     "ShapeRef": "valueShape"
-#     "Mand": "mandatory"
-#     "Rep": "repeatable"
 """
